<?php
/**
 * The template for displaying the Contact Info
 *
 * @package Decree Pro
 */

if ( ! function_exists( 'decree_contact_info_display' ) ) :
	/**
	 * Add Featured content.
	 *
	 * @uses action hook decree_before_content.
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_contact_info_display() {
		$output = '';

		// get data value from options.
		$options = decree_get_theme_options();
		$enable  = $options['contact_info_option'];

		if ( decree_check_section( $enable ) ) {
			// decree_flush_transients();.
			$output = get_transient( 'decree_contact_info' );

			if ( ! $output ) {
				echo '<!-- refreshing cache -->';

				$output = '
				<div id="contact-info-section" class="contact-info-footer">
					<div class="wrapper">
						<div class="content-info-wrapper">';

				if ( '' !== $options['contact_info_address'] || '' !== $options['contact_info_heading'] ) {
					$address = $options['contact_info_address'];

					if ( $options['contact_info_format_address'] ) {
						$address = apply_filters( 'the_content', $options['contact_info_address'] );
					}

					$output .= '
						<div class="content-info-details contact-information">
							<h2 class="contact-title">' . $options['contact_info_heading'] . '</h2>
							<div class="contact-address"><i class="fa fa-map-marker" aria-hidden="true"></i><span>' . $address . '</span></div>';

					if ( '' !== $options['contact_info_phone'] ) {
						$output .= '
							<p><i class="fa fa-phone" aria-hidden="true"></i><a target="_blank" title="Phone" href="tel:' . esc_attr( preg_replace( '/\s+/', '', $options['contact_info_phone'] ) ) . '">' . esc_html( $options['contact_info_phone'] ) . '</a></p>';
					}

					if ( '' !== $options['contact_info_fax'] ) {
						$output .= '
							<p><i class="fa fa-fax" aria-hidden="true"></i><a target="_blank" title="Fax" href="fax:' . esc_attr( preg_replace( '/\s+/', '', $options['contact_info_fax'] ) ) . '">' . esc_html( $options['contact_info_fax'] ) . '</a></p>';
					}

					if ( '' !== $options['contact_info_email'] ) {
						$output .= '
							<p><i class="fa fa-envelope" aria-hidden="true"></i><a target="_blank" title="' . esc_attr__( 'Email', 'decree-pro' ) . '" href="mailto:' . esc_attr( antispambot( sanitize_email( $options['contact_info_email'] ) ) ) . '">' . esc_html( antispambot( sanitize_email( $options['contact_info_email'] ) ) ) . '</a></p>';
					}

					if ( '' !== $options['contact_info_link'] ) {
						$target = '_blank';

						if ( ! $options['contact_info_link'] ) {
							$target = '_self';
						}
						$output .= '
							<p><a class="button-minimal" target="' . esc_attr( $target ) . '" title="' . esc_attr__( 'Email', 'decree-pro' ) . '" href="' . esc_url( $options['contact_info_link'] ) . '">' . esc_html( $options['contact_info_link_text'] ) . '</a></p>';
					}

					$output .= '
					</div><!-- .content-info-details -->';
				} // End if().

				if ( $options['contact_info_enable_social'] ) {
					$output .= '
					<div class="content-info-details stay-connected">
						<h2 class="contact-title">' . $options['contact_info_social_heading'] . '</h2>
						<p>' . decree_get_social_icons() . '</p>
					</div><!-- .content-info-details -->';
				}

					$output .= '
					</div><!-- .content-info-wrapper -->
				</div><!-- .wrapper -->';

				if ( 'none' !== $options['contact_info_bg'] ) {
					$output .= '
					<div class="wrapper content-map-wrapper">';

					if ( 'image' === $options['contact_info_bg'] ) {
						$output .= '<img src="' . esc_url( $options['contact_info_image'] ) . '" />';
					}

					if ( 'embed-code' === $options['contact_info_bg'] ) {
						$output .= wp_kses_stripslashes( $options['contact_info_code'] );
					}

					$output .= '
					</div><!-- .wrapper.content-map-wrapper -->';
				}

				$output .= '
				</div><!-- #contact-info-section -->';
			} // End if().

			set_transient( 'decree_contact_info', $output, 86940 );
		} // End if().

		echo $output;
	}
endif;
add_action( 'decree_footer', 'decree_contact_info_display', 20 );
