<?php
/**
* The template for adding additional theme options in Customizer
*
 * @package Decree Pro
*/

$wp_customize->add_section( 'decree_promotion_headline', array(
	'panel' => 'decree_theme_options',
	'title' => esc_html__( 'Promotion Headline', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_option]', array(
	'default'			=> $defaults['promo_head_option'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_option]', array(
	'choices'  	=> decree_section_visibility_options(),
	'label'    	=> esc_html__( 'Enable on', 'decree-pro' ),
	'section'  	=> 'decree_promotion_headline',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[promotion_headline_bg_image]', array(
	'default'			=> $defaults['promotion_headline_bg_image'],
	'sanitize_callback' => 'decree_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'decree_theme_options[promotion_headline_bg_image]', array(
	'active_callback' => 'decree_is_promo_head_active',
	'label'           => esc_html__( 'Background Image', 'decree-pro' ),
	'section'         => 'decree_promotion_headline',
	'settings'        => 'decree_theme_options[promotion_headline_bg_image]',
) ) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_type]', array(
	'default'			=> $defaults['promo_head_type'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_type]', array(
	'active_callback' => 'decree_is_promo_head_active',
	'choices'         => decree_news_ticker_types(),
	'label'           => esc_html__( 'Type', 'decree-pro' ),
	'section'         => 'decree_promotion_headline',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_show]', array(
	'default'			=> $defaults['promo_head_show'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_show]', array(
	'active_callback' => 'decree_is_page_post_category_promo_head_active',
	'choices'         => decree_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'decree-pro' ),
	'section'         => 'decree_promotion_headline',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_post]', array(
	'sanitize_callback'	=> 'decree_sanitize_page',
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_post]', array(
	'active_callback' => 'decree_is_post_promo_head_active',
	'input_attrs'     => array( 'style' => 'width: 100px;'),
	'label'           => esc_html__( 'Post ID', 'decree-pro' ),
	'section'         => 'decree_promotion_headline',
	'type'            => 'text',
) );

//page content
$wp_customize->add_setting( 'decree_theme_options[promo_head_page]', array(
	'sanitize_callback'	=> 'decree_sanitize_page',
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_page]', array(
	'active_callback' => 'decree_is_page_promo_head_active',
	'label'           => esc_html__( 'Select Page', 'decree-pro' ),
	'section'         => 'decree_promotion_headline',
	'type'            => 'dropdown-pages',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_category]', array(
	'sanitize_callback'	=> 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_category]', array(
	'active_callback'   => 'decree_is_category_promo_head_active',
	'choices'           => decree_get_category_list(),
	'label'             => esc_html__( 'Select Category', 'decree-pro' ),
	'section'           => 'decree_promotion_headline',
	'type'              => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_title]', array(
	'default' 			=> $defaults['promo_head_title'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_title]', array(
	'active_callback'   => 'decree_is_custom_promo_head_active',
	'description' => esc_html__( 'Appropriate Words: 10', 'decree-pro' ),
	'label'       => esc_html__( 'Title', 'decree-pro' ),
	'section'     => 'decree_promotion_headline',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_content]', array(
	'default' 			=> $defaults['promo_head_content'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_content]', array(
	'active_callback'   => 'decree_is_custom_promo_head_active',
	'description' => esc_html__( 'Appropriate Words: 15', 'decree-pro' ),
	'label'       => esc_html__( 'Content', 'decree-pro' ),
	'section'     => 'decree_promotion_headline',
	'type'        => 'textarea',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_button]', array(
	'default' 			=> $defaults['promo_head_button'],
	'sanitize_callback'	=> 'sanitize_text_field'
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_button]', array(
	'active_callback'   => 'decree_is_custom_promo_head_active',
	'description'	=> esc_html__( 'Appropriate Words: 3', 'decree-pro' ),
	'label'    	=> esc_html__( 'Button 1 Text ', 'decree-pro' ),
	'section' 	=> 'decree_promotion_headline',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_url]', array(
	'default' 			=> $defaults['promo_head_url'],
	'sanitize_callback'	=> 'esc_url_raw'
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_url]', array(
	'active_callback'   => 'decree_is_custom_promo_head_active',
	'label'    	=> esc_html__( 'Button 1 Link', 'decree-pro' ),
	'section' 	=> 'decree_promotion_headline',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_target_1]', array(
	'default' 			=> $defaults['promo_head_target_1'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_target_1]', array(
	'active_callback'   => 'decree_is_custom_promo_head_active',
	'label'    	=> esc_html__( 'Check to Open Button 1 Link in New Window/Tab', 'decree-pro' ),
	'section'  	=> 'decree_promotion_headline',
	'type'     	=> 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_button_2]', array(
	'default' 			=> $defaults['promo_head_button_2'],
	'sanitize_callback'	=> 'sanitize_text_field'
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_button_2]', array(
	'active_callback'   => 'decree_is_custom_promo_head_active',
	'description'	=> esc_html__( 'Appropriate Words: 3', 'decree-pro' ),
	'label'    	=> esc_html__( 'Button 2 Text ', 'decree-pro' ),
	'section' 	=> 'decree_promotion_headline',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_url_2]', array(
	'default' 			=> $defaults['promo_head_url_2'],
	'sanitize_callback'	=> 'esc_url_raw'
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_url_2]', array(
	'active_callback'   => 'decree_is_custom_promo_head_active',
	'label'    	=> esc_html__( 'Button 2 Link', 'decree-pro' ),
	'section' 	=> 'decree_promotion_headline',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'decree_theme_options[promo_head_target_2]', array(
	'default' 			=> $defaults['promo_head_target_2'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[promo_head_target_2]', array(
	'active_callback'   => 'decree_is_custom_promo_head_active',
	'label'    	=> esc_html__( 'Check to Open Button 2 Link in New Window/Tab', 'decree-pro' ),
	'section'  	=> 'decree_promotion_headline',
	'type'     	=> 'checkbox',
) );
