<?php
/**
 * The template for displaying the Slider
 *
 * @package Decree Pro
 */

if( ! function_exists( 'decree_featured_slider' ) ) :
	/**
	 * Add slider
	 *
	 * @uses action hook decree_before_content.
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_featured_slider() {
		//decree_flush_transients();
		$output = '';

		// get data value from options
		$options 		= decree_get_theme_options();
		$enable_slider 	= $options['featured_slider_option'];
		$slider_select 	= $options['featured_slider_type'];
		$image_loader	= $options['featured_slider_image_loader'];

		if ( decree_check_section( $enable_slider ) ) {
			if( ! $output = get_transient( 'decree_featured_slider' ) ) {
				echo '<!-- refreshing cache -->';
				$output = '
					<div id="feature-slider" class="sections">
						<div class="wrapper">
							<div class="cycle-slideshow"
								data-cycle-log="false"
								data-cycle-pause-on-hover="true"
								data-cycle-swipe="true"
								data-cycle-auto-height=container
								data-cycle-fx="'. esc_attr( $options['featured_slider_transition_effect'] ) . '"
								data-cycle-speed="'. esc_attr( $options['featured_slider_transition_length'] ) * 1000 . '"
								data-cycle-timeout="'. esc_attr( $options['featured_slider_transition_delay'] ) * 1000 . '"
								data-cycle-loader="'. esc_attr( $image_loader ) . '"
								data-cycle-slides="> article"
								>

								<!-- prev/next links -->
								<div class="cycle-prev"></div>
								<div class="cycle-next"></div>

								<!-- empty element for pager links -->
								<div class="cycle-pager"></div>';
								// Select Slider
								if ( 'demo' === $slider_select ) {
									$output .= decree_demo_slider( $options );
								}
								else if ( 'post' === $slider_select || 'page' === $slider_select || 'category' === $slider_select ) {
									$output .= decree_post_page_category_slider( $options );
								}
								elseif ( 'image' === $slider_select ) {
									$output .= decree_image_slider( $options );
								}

				$output .= '
							</div><!-- .cycle-slideshow -->
						</div><!-- .wrapper -->
					</div><!-- #feature-slider -->';
			}

			set_transient( 'decree_featured_slider', $output, 86940 );
		}

		echo $output;
	}
endif;
add_action( 'decree_before_content', 'decree_featured_slider', 10 );


if ( ! function_exists( 'decree_demo_slider' ) ) :
	/**
	 * This function to display featured posts slider
	 *
	 * @get the data value from customizer options
	 *
	 * @since Decree Pro 1.0
	 *
	 */
	function decree_demo_slider() {
		return '
		<article class="post demo-image-1 hentry slides displayblock">
			<figure class="slider-image">
				<a href="#">
					<img src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/slider1-1920x800.jpg" class="wp-post-image" alt="Real, Passionate, Trial Lawyers">
				</a>
			</figure>
			<div class="slider-content-wrapper">
				<div class="entry-container">
					<div class="container">
						<header class="entry-header">
							<h2 class="entry-title">
								<a href="#">Real, Passionate, Trial Lawyers</a>
							</h2>
						</header>
						<div class="entry-summary">
							<p>This is Featured Slider Section and you can edit this from Appearnce - Customize - Theme Options - Featured Slider. Details information of Featured Slider can be found in our theme instructions page <span class="more-button"><a class="button-minimal" href="#">Read More</a></span></p>
						</div><!-- .entry-summary -->
					</div><!-- .container -->
				</div><!-- .entry-container -->
			</div><!-- .slider-content-wrapper -->
		</article><!-- .slides -->

		<article class="post demo-image-2 hentry slides displaynone">
			<figure class="slider-image">
				<a title="Ocean" href="'. esc_url( home_url( '/' ) ) . '">
					<img src="'. trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/slider2-1920x800.jpg" class="wp-post-image" alt="SOcean" title="Ocean">
				</a>
			</figure>

			<div class="slider-content-wrapper">
				<div class="entry-container">
					<div class="container">
						<header class="entry-header">
							<h2 class="entry-title">
								<a title="Ocean" href="#">When We Believe in a Cause</a>
							</h2>
						</header>
						<div class="entry-summary">
							<p>This is Featured Slider Section and you can edit this from Appearnce - Customize - Theme Options - Featured Slider. Details information of Featured Slider can be found in our theme instructions page <span class="more-button"><a class="button-minimal" href="#">Read More</a></span></p>
						</div><!-- .entry-summary -->
					</div><!-- .container -->
				</div><!-- .entry-container -->
			</div><!-- .slider-content-wrapper -->
		</article><!-- .slides -->';
	}
endif; // decree_demo_slider


if ( ! function_exists( 'decree_post_page_category_slider' ) ) :
	/**
	 * This function to display featured posts/page/category slider
	 *
	 * @param $options: decree_theme_options from customizer
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_post_page_category_slider( $options ) {
		$quantity     = $options['featured_slider_number'];
		$no_of_post   = 0; // for number of posts
		$post_list    = array();// list of valid post/page ids
		$type         = $options['featured_slider_type'];
		$output     = '';

		$args = array(
			'orderby'             => 'post__in',
			'ignore_sticky_posts' => 1 // ignore sticky posts
		);

		//Get valid number of posts
		if( 'post' === $type || 'page' === $type  ) {
			if( 'page' === $type ) {
				$args['post_type'] = 'page';
			}

			for ( $i = 1; $i <= $quantity; $i++ ) {
				$post_id = '';

				if( 'post' === $type ) {
					$post_id = isset( $options['featured_slider_post_' . $i] ) ? $options['featured_slider_post_' . $i] : false;
				}
				elseif( 'page' === $type ) {
					$post_id = isset( $options['featured_slider_page_' . $i] ) ? $options['featured_slider_page_' . $i] : false;
				}

				if ( $post_id && '' !== $post_id ) {
					// Polylang Support.
					if ( class_exists( 'Polylang' ) ) {
						$post_id = pll_get_post( $post_id, pll_current_language() );
					}

					$post_list = array_merge( $post_list, array( $post_id ) );

					$no_of_post++;
				}
			}

			$args['post__in'] = $post_list;
		}
		elseif( 'category' === $type ) {
			$no_of_post = $quantity;

			if ( ! empty( $options['featured_slider_select_category'] ) ) {
				$args['category__in'] = $options['featured_slider_select_category'];
			}
		}

		if ( 0 === $no_of_post ) {
			return;
		}

		$args['posts_per_page'] = $no_of_post;

		$loop = new WP_Query( $args );

		while ( $loop->have_posts() ) {
			$loop->the_post();

			$title_attribute = the_title_attribute( 'echo=0' );

			$classes = 'post post-' . esc_attr( get_the_ID() ) . ' hentry slides displaynone';

			if ( 0 === $loop->current_post ) {
				$classes = 'post post-' . esc_attr( get_the_ID() ) . ' hentry slides displayblock';
			}

			$output .= '
			<article class="' . $classes . '">
				<figure class="slider-image">';
				if ( has_post_thumbnail() ) {
					$output .= '<a title="' . $title_attribute . '" href="' . esc_url( get_permalink() ) . '">
						'. get_the_post_thumbnail( get_the_ID(), 'decree-slider', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class'	=> 'attached-post-image' ) ).'
					</a>';
				}
				else {
					//Default value if there is no first image
					$decree_image = '<img class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-featured-image-1920x800.jpg" >';

					//Get the first image in page, returns false if there is no image
					$decree_first_image = decree_get_first_image( get_the_ID(), 'decree-slider', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'attached-post-image' ) );

					//Set value of image as first image if there is an image present in the page
					if ( '' !== $decree_first_image ) {
						$decree_image =	$decree_first_image;
					}

					$output .= '<a title="' . $title_attribute . '" href="' . esc_url( get_permalink() ) . '">
						'. $decree_image . '
					</a>';
				}

				$output .= '
				</figure><!-- .slider-image -->
				<div class="slider-content-wrapper">
					<div class="entry-container">
						<div class="container">
							<header class="entry-header">
								<h2 class="entry-title">
									<a title="' . $title_attribute . '" href="' . esc_url( get_permalink() ) . '">'.the_title( '<span>','</span>', false ).'</a>
								</h2>
							</header>
								';

							$output .= '<div class="entry-summary"><p>' . get_the_excerpt() . '</p></div><!-- .entry-summary -->';

							$output .= '
						</div><!-- .container -->
					</div><!-- .entry-container -->
				</div><!-- .slider-content-wrapper -->
			</article><!-- .slides -->';
		} // endwhile;

		wp_reset_postdata();

		return $output;
	}
endif; // decree_post_page_category_slider


if ( ! function_exists( 'decree_image_slider' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 */
function decree_image_slider( $options ) {
	$quantity	= $options['featured_slider_number'];

	$decree_image_slider = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {

		//Adding in Classes for Display block and none
		if ( $i === 1 ) { $classes = 'slider-image images-'.$i.' hentry slides displayblock'; } else { $classes = 'slider-image images-'.$i.' hentry slides displaynone'; }

		//Check Image Not Empty to add in the slides
		if ( ! empty ( $options[ 'featured_slider_image_'. $i ] ) ) {

			$imagetitle = ! empty ( $options[ 'featured_title_'. $i ] ) ? $options[ 'featured_title_'. $i ] : 'Featured Image-'.$i;

			$link = '';
			$target = '_self';
			$image = '<img alt="' . esc_attr( $imagetitle ) . '" class="wp-post-image" src="' . esc_url( $options[ 'featured_slider_image_' . $i ] ) . '" />';
			$content_title = '';
			$title = '';
			$content = '';


			//Checking Link
			if ( ! empty( $options[ 'featured_slider_button_link_'. $i ] ) ) {
				$link = $options[ 'featured_slider_button_link_'. $i ];

				//Checking Link Target
				if ( ! empty ( $options[ 'featured_target_'. $i ] ) ) {
					$target = '_blank';
				}

				//Checking image
				$image = '<a href="' . esc_url( $link ) . '" title="' . esc_attr( $imagetitle ) . '" target="' . $target . '"><img alt="' . esc_attr( $imagetitle ) . '" class="wp-post-image" src="' . esc_url( $options[ 'featured_slider_image_'. $i ] ) . '" /></a>';
			}

			//Checking Title
			if ( ! empty ( $options['featured_title_'. $i] ) ) {
				$content_title = $options['featured_title_'. $i];

				$title = '<header class="entry-header"><h2 class="entry-title"><span>' . esc_attr( $content_title ) . '</span></h2></header>';

				if ( '' !== $link ) {
					$title = '<header class="entry-header"><h2 class="entry-title"><a title="' . esc_attr( $content_title ) . '" href="' . esc_url( $link ) . '" target="' . $target . '"><span>' . esc_attr( $content_title ) . '</span></a></h2></header>';
				}
			}

			//Checking Content
			if ( ! empty ( $options['featured_content_'. $i] ) ) {
				$content = '<div class="entry-summary"><p>' . $options['featured_content_'. $i] . '</p></div><!-- .entry-summary -->';

				if ( '' !== $link ) {
					$content = '<div class="entry-summary"><p>' . $options['featured_content_'. $i] . '<span class="more-button"><a class="button-minimal" href="' . esc_url( $link ) . '">' . wp_kses_data( $options['featured_slider_button_text_'. $i] ) . '</a></span></p></div><!-- .entry-summary -->';
				}
			}

			//Content Opening and Closing
			if ( ! empty ( $content_title ) || ! empty ( $content ) ) {
				$contentopening = '<div class="slider-content-wrapper"><div class="entry-container"><div class="container"><p>';
				$contentclosing = '</p></div><!-- .container --></div><!-- .entry-container --></div><!-- .slider-content-wrapper -->';
			}
			else {
				$contentopening = '';
				$contentclosing = '';
			}

			$decree_image_slider .= '
			<article class="image-slides hentry ' . $classes . '">
				<figure class="slider-image">
					'. $image . '
				</figure>
				' . $contentopening . $title . $content . $contentclosing . '
			</article><!-- .slides --> ';
		}
	}
	return $decree_image_slider;
}
endif; //decree_image_slider
