<?php
/**
 * The template for displaying the Hero Content
 *
 * @package Decree Pro
 */


if ( ! function_exists( 'decree_hero_content_display' ) ) :
	/**
	* Add Featured content.
	*
	* @uses action hook decree_before_content.
	*
	* @since Decree Pro 1.0
	*/
	function decree_hero_content_display() {
		//decree_flush_transients();
		$output = '';

		// get data value from options
		$options        = decree_get_theme_options();
		$enable_content = $options['hero_content_option'];
		$content_select = $options['hero_content_type'];

		if ( decree_check_section( $enable_content ) ) {
			if ( !$output = get_transient( 'decree_hero_content' ) ) {
				echo '<!-- refreshing cache -->';

				$classes[] = $content_select ;

				$output ='
					<div id="hero-section" class="sections ' . implode( ' ', $classes ) . '">
						<div class="wrapper">';
							// Select content
							if ( 'demo' === $content_select ) {
								$output .= decree_demo_hero_content();
							}
							elseif ( 'post' === $content_select || 'page' === $content_select || 'category' === $content_select ) {
								$output .= decree_post_page_category_hero_content( $options );
							}
							elseif ( 'image' === $content_select ) {
								$output .= decree_custom_hero_content( $options );
							}

					$output .= '
						</div><!-- .wrapper -->
					</div><!-- #hero-section -->';
			}

			set_transient( 'decree_hero_content', $output, 86940 );
		}
		echo $output;
	}
endif;
add_action( 'decree_before_content', 'decree_hero_content_display', 30 );


if ( ! function_exists( 'decree_demo_hero_content' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @get the data value from customizer options
	 *
	 * @since Decree Pro 1.0
	 *
	 */
	function decree_demo_hero_content() {
		return '
		<article class="post-0 page type-page status-publish has-post-thumbnail hentry" id="post-0">
			<figure class="featured-image">
		    	<a href="#" rel="bookmark">
		        	<img alt="" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/about-635x476.jpg">
		        </a>
			</figure>
			<div class="entry-container">
				<div class="entry-container-wrap">
					<header class="entry-header">
						<h2 class="entry-title section-title"><a href="#">About US: Lawyer</a></h2>
					</header><!-- .entry-header -->

					<div class="entry-summary">
						<p>A lawyer is a person who practices law, as an advocate, barrister, attorney, counselor or solicitor or chartered legal executive. Working as a lawyer involves the practical application of abstract legal theories and knowledge to solve specific individualized problems, or to advance the interests of those who hire lawyers to perform legal services. <span class="more-button"><a class="button-minimal" href="#">Read More ...</a></span>
					</div><!-- .entry-summary -->
				</div><!-- .entry-container-wrap -->
			</div><!-- .entry-container -->
		</article><!-- .hentry -->';
	}
endif; // decree_demo_hero_content


if ( ! function_exists( 'decree_post_page_category_hero_content' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @param $options: decree_theme_options from customizer
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_post_page_category_hero_content( $options ) {
		$quantity   = $options['hero_content_number'];
		$no_of_post = 0; // for number of posts
		$post_list  = array();// list of valid post/page ids
		$type       = $options['hero_content_type'];
		$output     = '';

		$args = array(
			'orderby'             => 'post__in',
			'ignore_sticky_posts' => 1 // ignore sticky posts
		);

		//Get valid number of posts
		if ( 'post' === $type || 'page' === $type ) {
			if( 'page' === $type ) {
				$args['post_type'] = 'page';
			}

			for ( $i = 1; $i <= $quantity; $i++ ) {
				$post_id = '';

				if ( 'post' === $type ) {
					$post_id = isset( $options['hero_content_post_' . $i] ) ? $options['hero_content_post_' . $i] : false;
				}
				elseif ( 'page' === $type ) {
					$post_id = isset( $options['hero_content_page_' . $i] ) ? $options['hero_content_page_' . $i] : false;
				}

				if ( $post_id && '' !== $post_id ) {
					// Polylang Support.
					if ( class_exists( 'Polylang' ) ) {
						$post_id = pll_get_post( $post_id, pll_current_language() );
					}

					$post_list = array_merge( $post_list, array( $post_id ) );

					$no_of_post++;
				}
			}

			$args['post__in'] = $post_list;
		}
		elseif ( 'category' === $type ) {
			$no_of_post = $quantity;

			if ( ! empty( $options['hero_content_select_category'] ) ) {
				$args['category__in'] = $options['hero_content_select_category'];
			}

			$args['post_type'] = 'post';
		}

		if ( 0 === $no_of_post ) {
			return;
		}

		$args['posts_per_page'] = $no_of_post;

		$loop = new WP_Query( $args );

		while ( $loop->have_posts() ) {
			$loop->the_post();

			$title_attribute = the_title_attribute( 'echo=0' );

			$output .= '
				<article id="post-' . esc_attr( $loop->current_post ) . '" class="post-' . esc_attr( $loop->current_post ) . ' hentry has-post-thumbnail">';

				//Default value if there is no first image
				$image = '<img class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-featured-image-635x476.jpg" >';

				if ( has_post_thumbnail() ) {
					$image = get_the_post_thumbnail( get_the_ID(), 'decree-hero', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );
				}
				else {
					//Get the first image in page, returns false if there is no image
					$first_image = decree_get_first_image( get_the_ID(), 'decree-hero', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );

					//Set value of image as first image if there is an image present in the page
					if ( $first_image ) {
						$image = $first_image;
					}
				}

				$output .= '
					<figure class="featured-image">
						<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">
						'. $image . '
						</a>
					</figure>';

				if ( $options['hero_content_enable_title'] || 'hide-content' !== $options['hero_content_show'] ) {
				$output .= '
					<div class="entry-container">
						<div class="entry-container-wrap">';

					if ( $options['hero_content_enable_title'] ) {
						$output .= '
						<header class="entry-header">
							<h2 class="entry-title section-title">
								<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . the_title( '','', false ) . '</a>
							</h2>
						</header>';
					}

					if ( 'excerpt' === $options['hero_content_show'] ) {
						//Show Excerpt
						$output .= '
						<div class="entry-summary">
							<p>' . get_the_excerpt() . '</p>
						</div><!-- .entry-content -->';
					}
					elseif ( 'full-content' === $options['hero_content_show'] ) {
						//Show Content
						$content = apply_filters( 'the_content', get_the_content() );
						$content = str_replace( ']]>', ']]&gt;', $content );
						$output .= '<div class="entry-content">' . $content . '</div><!-- .entry-content -->';
					}
				}
				$output .= '
						</div><!-- .entry-container-wrap -->
					</div><!-- .entry-container -->
				</article><!-- .post-'. esc_attr( $loop->current_post ) . ' -->';
			} //endwhile

		wp_reset_postdata();

		return $output;
	}
endif; // decree_post_page_category_hero_content


if ( ! function_exists( 'decree_custom_hero_content' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @get the data value from theme options
	 * @displays on the index
	 *
	 * @useage Featured Image, Title and Excerpt of Post
	 *
	 * @uses set_transient
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_custom_hero_content( $options ) {
		$quantity = $options['hero_content_number'];
		$output   = '';

		for ( $i = 1; $i <= $quantity; $i++ ) {
			if ( ! empty( $options[ 'hero_content_target_' . $i ] ) ) {
				$target = '_blank';
			} else {
				$target = '_self';
			}

			//Checking Link
			if ( ! empty( $options[ 'hero_content_link_' . $i ] ) ) {
				//support qTranslate plugin
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$link = qtrans_convertURL(  $options[ 'hero_content_link_' . $i ] );
				}
				else {
					$link =  $options[ 'hero_content_link_' . $i ];
				}
			}
			else {
				$link = '#';
			}

			//Checking Title
			if ( ! empty( $options[ 'hero_content_title_'. $i ] ) ) {
				$title = $options[ 'hero_content_title_'. $i ];
			}
			else {
				$title = '';
			}

			//Checking Content
			if ( ! empty( $options[ 'hero_content_content_'. $i ] ) ) {
				$content = $options[ 'hero_content_content_'. $i ];
			}
			else {
				$content = '';
			}

			$button_text   = '';
			$button_link   = '#';
			$button_target = '_self';

			//Checking Button Elements
			if ( ! empty( $options['hero_content_button_text_' . $i] ) ) {
				$button_text = $options['hero_content_button_text_' . $i];

				if ( ! empty( $options['hero_content_button_link_' . $i] ) ) {
					//support qTranslate plugin
					if ( function_exists( 'qtrans_convertURL' ) ) {
						$button_link = qtrans_convertURL(  $options['hero_content_button_link_' . $i] );
					}
					else {
						$button_link = $options['hero_content_button_link_' . $i];
					}
				}

				if ( ! empty( $options['hero_content_button_target_' . $i] ) ) {
					$button_target = '_blank';
				}
			}

			$output .= '
				<article id="image-'.$i.'" class="post hentry hero-image-content has-post-thumbnail">';
					if ( ! empty( $options[ 'hero_content_image_' . $i ] ) ) {
						$output .= '
						<figure class="featured-image">
							<a title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '" target="' . esc_attr( $target ) . '">
								<img src="' . esc_url( $options[ 'hero_content_image_' . $i ] ) . '" class="wp-post-image" alt="' . esc_attr( $title ) . '" title="' . esc_attr( $title ) . '">
							</a>
						</figure>';
					}

					if ( '' !== $title || '' !== $content || '' !== $button_text ) {
						$output .= '
						<div class="entry-container">
							<div class="entry-container-wrap">';
						if ( '' !== $title ) {
							$output .= '
							<header class="entry-header">
								<h2 class="entry-title section-title">
									' . wp_kses_post( $title ) . '
								</h2>
							</header>';
						}
						if (  '' !== $content || '' !== $button_text ) {
							$output .= '
							<div class="entry-summary">
								' . $content . '

								<span class="readmore"><a href="' . esc_url( $button_link ) . '" class="button" target="' . esc_attr( $button_target ) . '">'. esc_html( $button_text ) . '</a></span>
							</div>';
						}

						$output .= '
							</div><!-- .entry-container-wrap -->
						</div><!-- .entry-container -->';
					}
				$output .= '
				</article><!-- .hero-custom-'.$i.' -->';
		}
		return $output;
	}
endif; //decree_custom_content
