<?php
/**
 * The template for displaying custom menus
 *
 * @package Decree Pro
 */


if ( ! function_exists( 'decree_primary_menu' ) ) :
/**
 * Shows the Primary Menu
 *
 * default load in sidebar-header-right.php
 */
function decree_primary_menu() {
    $options  = decree_get_theme_options();
    if ( ! $options['primary_menu_disable'] ) :
    	?>
        <div id="primary-menu" class="menu-primary">
            <div class="wrapper">
                <button id="menu-toggle-primary" class="menu-toggle"><?php esc_html_e( 'Menu', 'decree-pro' ); ?></button>

                <div id="site-header-menu">
                    <nav id="site-navigation" class="main-navigation nav-primary <?php echo ( ! $options['primary_search_disable']  ) ? 'search-enabled' : '';?>" role="navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'decree-pro' ); ?>">
                        <h3 class="screen-reader-text"><?php _e( 'Primary menu', 'decree-pro' ); ?></h3>
                        <?php
                            if ( has_nav_menu( 'primary' ) ) {
                                $args = array(
                                    'theme_location'    => 'primary',
                                    'menu_class'        => 'menu decree-nav-menu',
                                    'container'         => false
                                );
                                wp_nav_menu( $args );
                            }
                            else {
                                wp_page_menu( array( 'menu_class'  => 'default-page-menu' ) );
                            }
                            if( ! $options['primary_search_disable'] ) :
                                ?>
                                <div id="search-toggle">
                                    <a class="screen-reader-text" href="#search-container"><?php esc_html_e( 'Search', 'decree-pro' ); ?></a>
                                </div>

                                <div id="search-container" class="displaynone">
                                    <?php get_Search_form(); ?>
                                </div>
                                <?php
                            endif;
                        ?>
                    </nav><!-- .nav-primary -->
                </div><!-- #site-header-menu -->
            </div><!-- .wrapper -->
        </div><!-- #primary-menu-wrapper -->
        <?php
    endif;
}
endif; //decree_primary_menu
add_action( 'decree_after_header', 'decree_primary_menu', 20 );


if ( ! function_exists( 'decree_add_page_menu_class' ) ) :
/**
 * Filters wp_page_menu to add menu class  for default page menu
 *
 */
function decree_add_page_menu_class( $ulclass ) {
  return preg_replace( '/<ul>/', '<ul class="menu decree-nav-menu">', $ulclass, 1 );
}
endif; //decree_add_page_menu_class
add_filter( 'wp_page_menu', 'decree_add_page_menu_class', 90 );


if ( ! function_exists( 'decree_secondary_menu' ) ) :
/**
 * Shows the Secondary Menu
 *
 * default load in sidebar-header-right.php
 */
function decree_secondary_menu() {
    if ( has_nav_menu( 'secondary' ) ) {
	?>
        <div id="secondary-menu" class="menu-secondary">
            <div class="wrapper">
            	<button id="menu-toggle-secondary" class="menu-toggle main-navigation"><?php esc_html_e( 'Menu', 'decree-pro' ); ?></button>
                <div id="site-secondary-menu">
                    <nav id="nav-secondary" class="nav-secondary" role="navigation" aria-label="<?php esc_attr_e( 'Secondary Menu', 'decree-pro' ); ?>">
                        <h3 class="screen-reader-text"><?php _e( 'Secondary menu', 'decree-pro' ); ?></h3>
                        <?php
                            $args = array(
                                'theme_location' => 'secondary',
                                'menu_class'     => 'menu decree-nav-menu'
                            );
                            wp_nav_menu( $args );
                        ?>
                    </nav><!-- .nav-secondary -->
                </div><!-- #site-secondary-menu -->
            </div><!-- .wrapper -->
        </div><!-- #secondary-menu -->
<?php
    }
}
endif; //decree_secondary_menu
add_action( 'decree_after_header', 'decree_secondary_menu', 40 );


if ( ! function_exists( 'decree_footer_menu' ) ) :
/**
 * Shows the Footer Menu
 *
 * default load in sidebar-header-right.php
 */
function decree_footer_menu() {
	if ( has_nav_menu( 'footer' ) ) {
    ?>
	<nav class="nav-footer" role="navigation" aria-label="<?php esc_attr_e( 'Footer Menu', 'decree-pro' ); ?>">
        <div class="wrapper">
            <h3 class="assistive-text"><?php _e( 'Footer menu', 'decree-pro' ); ?></h3>
            <?php
                $args = array(
                    'theme_location' => 'footer',
                    'menu_class'     => 'menu decree-nav-menu',
                    'depth'          => 1
                );
                wp_nav_menu( $args );
            ?>
    	</div><!-- .wrapper -->
    </nav><!-- .nav-footer -->
<?php
    }
}
endif; //decree_footer_menu
add_action( 'decree_footer', 'decree_footer_menu', 50 );


if ( ! function_exists( 'decree_header_top_menu' ) ) :
/**
 * Shows the Header Top Menu
 *
 * default load in sidebar-header-top.php
 */
function decree_header_top_menu() {
    $options      = decree_get_theme_options();
    $social_icons = decree_get_social_icons();

    if ( has_nav_menu( 'header-top' ) || ( ! $options['disable_social_icons'] && '' !== $social_icons ) ) {
    ?>
    <div id="header-top-menu" class="menu-header-top">
        <?php if ( has_nav_menu( 'header-top' ) ) { ?>
            <button id="menu-toggle-header-top" class="menu-toggle main-navigation"><?php esc_html_e( 'Menu', 'decree-pro' ); ?></button>
            <div id="site-header-top-menu">
                <nav id="nav-header-top" class="nav-header-top" role="navigation" aria-label="<?php esc_attr_e( 'Header Menu', 'decree-pro' ); ?>">
                    <h3 class="assistive-text"><?php _e( 'Header menu', 'decree-pro' ); ?></h3>
                    <div class="wrapper">
                        <?php
                            $args = array(
                                'theme_location' => 'header-top',
                                'menu_class'     => 'menu decree-nav-menu'
                            );
                            wp_nav_menu( $args );
                        ?>
                    </div><!-- .wrapper -->
                </nav><!-- .nav-header-top -->
                <?php
                if ( ! $options['disable_social_icons'] && '' !== $social_icons ) { ?>
                    <div class="header-right-social-icons widget_decree_social_icons">
                       <?php echo $social_icons; ?>
                    </div><!-- #header-right-social-icons -->
                <?php
                } ?>
            </div><!-- .site-header-top-menu -->
        <?php
        }
        else { ?>
            <div class="header-right-social-icons widget_decree_social_icons">
                <?php echo $social_icons; ?>
            </div><!-- #header-right-social-icons -->
        <?php
        } ?>

    </div><!-- #header-top-menu -->
    <?php
    }
}
endif; //decree_header_top_menu
